@@ -44,7 +44,7 @@
 
 class Smb4KSuperUserOptions : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
