@@ -49,19 +49,19 @@ Smb4KUserInterfaceOptions::Smb4KUserInterfaceOptions( TQWidget *parent, const ch
   TQGridLayout *main_wd_layout = new TQGridLayout( main_wd_widget );
   main_wd_layout->setSpacing( 10 );
 
-  TQButtonGroup *shares_view   = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Shares View" ),
+  TQButtonGroup *shares_view   = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Shares View" ),
                                 main_wd_widget, "kcfg_SharesView" );
 
   shares_view->insert( new TQRadioButton( i18n( "Show mounted shares in an icon view" ), shares_view ), Smb4KSettings::EnumSharesView::IconView );
 
   shares_view->insert( new TQRadioButton( i18n( "Show mounted shares in a list view" ), shares_view ), Smb4KSettings::EnumSharesView::ListView );
 
-  TQButtonGroup *bookmarks_grp = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Bookmarks" ),
+  TQButtonGroup *bookmarks_grp = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Bookmarks" ),
                                 main_wd_widget, "BookmarksBox" );
 
   (void) new TQCheckBox( i18n( "Show custom bookmark label if available" ), bookmarks_grp, "kcfg_ShowCustomBookmarkLabel" );
 
-  TQButtonGroup *tray_group    = new TQButtonGroup( 1, Qt::Horizontal, i18n( "System Tray" ),
+  TQButtonGroup *tray_group    = new TQButtonGroup( 1, TQt::Horizontal, i18n( "System Tray" ),
                                 main_wd_widget, "SystemTrayBox" );
 
   (void) new TQCheckBox( i18n( "Embed application into the system tray" ), tray_group, "kcfg_EmbedIntoSystemTray" );
@@ -80,20 +80,20 @@ Smb4KUserInterfaceOptions::Smb4KUserInterfaceOptions( TQWidget *parent, const ch
   TQGridLayout *browser_layout = new TQGridLayout( browser_widget );
   browser_layout->setSpacing( 10 );
 
-  TQButtonGroup *remoteGroup = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Remote Shares" ),
+  TQButtonGroup *remoteGroup = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Remote Shares" ),
                               browser_widget, "BrowserRemoteSharesBox" );
   (void) new TQCheckBox( i18n( "Show printer shares" ), remoteGroup, "kcfg_ShowPrinterShares" );
   TQCheckBox *hidden = new TQCheckBox( i18n( "Show hidden shares" ), remoteGroup, "kcfg_ShowHiddenShares" );
   (void) new TQCheckBox( i18n( "Show IPC$ shares" ), remoteGroup, "kcfg_ShowHiddenIPCShares" );
   (void) new TQCheckBox( i18n( "Show ADMIN$ shares" ), remoteGroup, "kcfg_ShowHiddenADMINShares" );
 
-  TQButtonGroup *columnsGroup = new TQButtonGroup( 2, Qt::Horizontal, i18n( "Columns" ),
+  TQButtonGroup *columnsGroup = new TQButtonGroup( 2, TQt::Horizontal, i18n( "Columns" ),
                                browser_widget, "BrowserColumnsBox" );
   (void) new TQCheckBox( i18n( "Show type" ), columnsGroup, "kcfg_ShowType" );
   (void) new TQCheckBox( i18n( "Show IP address" ), columnsGroup, "kcfg_ShowIPAddress" );
   (void) new TQCheckBox( i18n( "Show comment" ), columnsGroup, "kcfg_ShowComment" );
 
-  TQButtonGroup *netTooltipsGroup = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Tooltips" ),
+  TQButtonGroup *netTooltipsGroup = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Tooltips" ),
                                    browser_widget, "BrowserTooltipsBox" );
   (void) new TQCheckBox( i18n( "Show tooltip with information about a network item" ), netTooltipsGroup, "kcfg_ShowNetworkItemToolTip" );
 
@@ -111,21 +111,21 @@ Smb4KUserInterfaceOptions::Smb4KUserInterfaceOptions( TQWidget *parent, const ch
   TQGridLayout *shares_layout = new TQGridLayout( shares_widget );
   shares_layout->setSpacing( 10 );
 
-  TQButtonGroup *shares_group = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Mounted Shares" ),
+  TQButtonGroup *shares_group = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Mounted Shares" ),
                               shares_widget, "SharesIconGroupBox" );
   (void) new TQCheckBox( i18n( "Show mount point instead of share name" ), shares_group, "kcfg_ShowMountPoint" );
   (void) new TQCheckBox( i18n( "Show all shares that are mounted on the system" ), shares_group, "kcfg_ShowAllShares" );
 
-  TQButtonGroup *dnd_group = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Drag and Drop" ),
+  TQButtonGroup *dnd_group = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Drag and Drop" ),
                             shares_widget, "DragnDropBox" );
   (void) new TQCheckBox( i18n( "Allow dropping of files and directories onto shares" ), dnd_group, "kcfg_EnableDropSupport" );
   (void) new TQCheckBox( i18n( "Allow dragging of shares" ), dnd_group, "kcfg_EnableDragSupport" );
 
-  TQButtonGroup *sharesTooltipGroup = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Tooltips" ),
+  TQButtonGroup *sharesTooltipGroup = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Tooltips" ),
                                      shares_widget, "SharesTooltipsBox" );
   (void) new TQCheckBox( i18n( "Show tooltip with information about a share" ), sharesTooltipGroup, "kcfg_ShowShareToolTip" );
 
-  TQButtonGroup *list_view_group = new TQButtonGroup( 2, Qt::Horizontal, i18n( "List View" ),
+  TQButtonGroup *list_view_group = new TQButtonGroup( 2, TQt::Horizontal, i18n( "List View" ),
                                   shares_widget, "SharesListViewBox" );
 
 #ifndef __FreeBSD__
@@ -155,7 +155,7 @@ Smb4KUserInterfaceOptions::Smb4KUserInterfaceOptions( TQWidget *parent, const ch
   TQGridLayout *preview_layout = new TQGridLayout( preview_widget );
   preview_layout->setSpacing( 10 );
 
-  TQButtonGroup *previewFilesGroup = new TQButtonGroup( 1, Qt::Horizontal, i18n( "Hidden Files and Directories" ), preview_widget, "HiddenFilesBox" );
+  TQButtonGroup *previewFilesGroup = new TQButtonGroup( 1, TQt::Horizontal, i18n( "Hidden Files and Directories" ), preview_widget, "HiddenFilesBox" );
   (void) new TQCheckBox( i18n( "Preview hidden files and directories" ), previewFilesGroup, "kcfg_PreviewHiddenItems" );
 
   TQSpacerItem *spacer4 = new TQSpacerItem( 0, 0, TQSizePolicy::Preferred, TQSizePolicy::Expanding );
@@ -172,8 +172,8 @@ Smb4KUserInterfaceOptions::Smb4KUserInterfaceOptions( TQWidget *parent, const ch
   addTab( preview_widget, i18n( "Preview Dialog" ) );
 
   // Add connections:
-  connect( hidden, TQT_SIGNAL( stateChanged( int ) ),
-           this,   TQT_SLOT( slotShowHiddenShares( int ) ) );
+  connect( hidden, TQ_SIGNAL( stateChanged( int ) ),
+           this,   TQ_SLOT( slotShowHiddenShares( int ) ) );
 
   // Do last adjustments:
   slotShowHiddenShares( hidden->state() );
@@ -186,7 +186,7 @@ Smb4KUserInterfaceOptions::~Smb4KUserInterfaceOptions()
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 
@@ -194,13 +194,13 @@ void Smb4KUserInterfaceOptions::slotShowHiddenShares( int state )
 {
   if ( state == TQCheckBox::On )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ShowHiddenIPCShares", TQCHECKBOX_OBJECT_NAME_STRING )) )->setEnabled( true );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ShowHiddenADMINShares", TQCHECKBOX_OBJECT_NAME_STRING )) )->setEnabled( true );
+    static_cast<TQCheckBox *>( child( "kcfg_ShowHiddenIPCShares", "TQCheckBox" ) )->setEnabled( true );
+    static_cast<TQCheckBox *>( child( "kcfg_ShowHiddenADMINShares", "TQCheckBox" ) )->setEnabled( true );
   }
   else if ( state == TQCheckBox::Off )
   {
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ShowHiddenIPCShares", TQCHECKBOX_OBJECT_NAME_STRING )) )->setEnabled( false );
-    static_cast<TQCheckBox *>( TQT_TQWIDGET(child( "kcfg_ShowHiddenADMINShares", TQCHECKBOX_OBJECT_NAME_STRING )) )->setEnabled( false );
+    static_cast<TQCheckBox *>( child( "kcfg_ShowHiddenIPCShares", "TQCheckBox" ) )->setEnabled( false );
+    static_cast<TQCheckBox *>( child( "kcfg_ShowHiddenADMINShares", "TQCheckBox" ) )->setEnabled( false );
   }
 }
 
