@@ -43,7 +43,7 @@
 
 class Smb4KUserInterfaceOptions : public TQTabWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
   public:
