@@ -31,7 +31,7 @@
 #include <tqstring.h>
 #include <tqcstring.h>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 /**
  * This class provides a container for the authentication data.
@@ -40,7 +40,7 @@
  */
 
 
-class KDE_EXPORT Smb4KAuthInfo
+class TDE_EXPORT Smb4KAuthInfo
 {
   public:
     /**
