@@ -59,14 +59,14 @@ Smb4KPrint::Smb4KPrint( TQObject *parent, const char *name ) : TQObject( parent,
 
   m_working = false;
 
-  connect( m_proc, TQT_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
-           this,   TQT_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
+  connect( m_proc, TQ_SIGNAL( receivedStdout( TDEProcess *, char *, int ) ),
+           this,   TQ_SLOT( slotReceivedStdout( TDEProcess *, char *, int ) ) );
 
-  connect( m_proc, TQT_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
-           this,   TQT_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
+  connect( m_proc, TQ_SIGNAL( receivedStderr( TDEProcess *, char *, int ) ),
+           this,   TQ_SLOT( slotReceivedStderr( TDEProcess *, char *, int ) ) );
 
-  connect( m_proc, TQT_SIGNAL( processExited( TDEProcess * ) ),
-           this,   TQT_SLOT( slotProcessExited( TDEProcess * ) ) );
+  connect( m_proc, TQ_SIGNAL( processExited( TDEProcess * ) ),
+           this,   TQ_SLOT( slotProcessExited( TDEProcess * ) ) );
 }
 
 
@@ -289,7 +289,7 @@ void Smb4KPrint::printText()
 
 
 /////////////////////////////////////////////////////////////////////////////
-// TQT_SLOT IMPLEMENTATIONS
+// SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
 
 void Smb4KPrint::slotReceivedStdout( TDEProcess *, char *buf, int len )
@@ -333,7 +333,7 @@ void Smb4KPrint::slotProcessExited( TDEProcess * )
       if ( passwordHandler()->askpass( m_info->workgroup(), m_info->host(), m_info->printer(), state ) )
       {
         retry = true;
-        TQTimer::singleShot( 50, this, TQT_SLOT( slotRetry() ) );
+        TQTimer::singleShot( 50, this, TQ_SLOT( slotRetry() ) );
       }
     }
     else
